#ifndef NT2_INCLUDE_FUNCTIONS_EXP2_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_EXP2_HPP_INCLUDED

#include <nt2/exponential/include/functions/exp2.hpp>

#endif
